Register
Keywords: PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum

| Welcome, Guest. Please login or register. Did you miss your activation email? December 06, 2014, 01:13:01 AM
News: Welcome to the GuerrillaGardening.org Community, a place for guerrillas and wannabe guerrillas from around the world. Enlist with a username and password to share your guerrilla gardening plans, activity and advice. Find support or just go for it solo, sow the seed and get something growing. Click here to return to the home page: www.GuerrillaGardening.org You can also connect with people at the GuerrillaGardening.org Facebook group here: http://www.facebook.com/guerrillagardening TIP: To get alerts to replies to your messages click PROFILE then click "Look and Layout Preferences" on the left hand side menu. There is a check box to get alerts, and a check box to see recent posts at the top.

Register - Required Information
Choose username: Used only for identification by SMF. |
Email: This must be a valid email address. | Hide email address from public?
Choose password: |
Verify password: |
To prevent automatic filling in of the form you should perform a task: |
Welcome to the GuerrillaGardening.org Community, a place where you can share and meet guerrilla gardeners and aspiring guerrilla gardeners in your local area and around the world. Your registration will be manually approved within about 24 hours - we have this delay to try and minimise the risk of spamming. If you need to contact someone about this e-mail "community@guerrillagardening.org" In signing up to the Community there are a few things we need you to respect and agree with, and in the paragraphs below is lots of standard approvals that you must accept before proceeding including the obvious: no abusive or obscene postings, and no irrelevant commercial messages - including those you may wish to include in your member signatures or footers. You agree, through your use of this forum, that you will not post any material which is false, defamatory, inaccurate, abusive, vulgar, harassing, obscene, profane, sexually oriented, threatening, adult material, or otherwise in violation of any International law. You also agree not to post any copyrighted material unless you own the copyright or you have written consent from the owner of the copyrighted material. Spam, flooding, advertisements, chain letters, pyramid schemes, and solicitations are also forbidden on this forum. Note that it is impossible for the staff or the owners of this forum to confirm the validity of posts. Please remember that we do not actively monitor the posted messages, and as such, are not responsible for the content contained within. We do not warrant the accuracy, completeness, or usefulness of any information presented. The posted messages express the views of the author, and not necessarily the views of this forum, its staff, its subsidiaries, or this forum's owner. Anyone who feels that a posted message is objectionable is encouraged to notify an administrator or moderator of this forum immediately. The staff and the owner of this forum reserve the right to remove objectionable content, within a reasonable time frame, if they determine that removal is necessary. This is a manual process, however, please realize that they may not be able to remove or edit particular messages immediately. This policy applies to member profile information as well. You remain solely responsible for the content of your posted messages. Furthermore, you agree to indemnify and hold harmless the owners of this forum, any related websites to this forum, its staff, and its subsidiaries. The owners of this forum also reserve the right to reveal your identity (or any other related information collected on this service) in the event of a formal complaint or legal action arising from any situation caused by your use of this forum. You have the ability, as you register, to choose your username. We advise that you keep the name appropriate. With this user account you are about to register, you agree to never give your password out to another person except an administrator, for your protection and for validity reasons. You also agree to NEVER use another person's account for any reason. We also HIGHLY recommend you use a complex and unique password for your account, to prevent account theft. You will receive occasional news letters but can unsubscribe if you so wish. After you register you will need to wait up to 24 hours for registration to be approved before you can login to this forum. You will be able to fill out a detailed profile. It is your responsibility to present clean and accurate information. Any information the forum owner or staff determines to be inaccurate or vulgar in nature will be removed, with or without prior notice. Appropriate sanctions may be applicable. Please note that with each post, your IP address is recorded, in the event that you need to be banned from this forum or your ISP contacted. This will only happen in the event of a major violation of this agreement. Also note that the software places a cookie, a text file containing bits of information (such as your username and password), in your browser's cache. This is ONLY used to keep you logged in/out. The software does not collect or send any other form of information to your computer.
I Agree

Login with username, password and session length

| Powered by SMF 1.1.19 | SMF © 2013, Simple Machines |

Loading...